.. _all-salt.auth:

=================================
Full list of builtin auth modules
=================================

.. currentmodule:: salt.auth

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    auto
    keystone
    ldap
    pam
    stormpath_mod
